@@ -5,11 +5,11 @@ use Mouse::Role;
 
 # ABSTRACT: Web::API - A Simple base module to implement almost every RESTful API with just a few lines of configuration
 
-our $VERSION = '1.1'; # VERSION
+our $VERSION = '1.2'; # VERSION
 
 use LWP::UserAgent;
 use HTTP::Cookies;
-use Data::Dumper;
+use Data::Dump 'dump';
 use XML::Simple;
 use URI::Escape::XS qw/uri_escape uri_unescape/;
 use JSON;
@@ -236,6 +236,13 @@ sub nonce {
 }
 
 
+sub log { ## no critic (ProhibitBuiltinHomonyms)
+    my ($self, $msg) = @_;
+    print STDERR __PACKAGE__ . ': ' . $msg . $/;
+    return;
+}
+
+
 sub decode {
     my ($self, $content, $content_type) = @_;
 
@@ -255,7 +262,7 @@ sub decode {
         }
     };
     return { error => "couldn't decode payload using $content_type: $@\n"
-            . Dumper($content) }
+            . dump($content) }
         if ($@ || ref \$content ne 'SCALAR');
 
     return $data;
@@ -281,7 +288,7 @@ sub encode {
         }
     };
     return { error => "couldn't encode payload using $content_type: $@\n"
-            . Dumper($options) }
+            . dump($options) }
         if ($@ || ref \$payload ne 'SCALAR');
 
     return $payload;
@@ -331,9 +338,8 @@ sub talk {
             $oauth_req->sign;
         }
         default {
-            print "WARNING: auth_type "
-                . $self->auth_type
-                . " not supported yet\n"
+            $self->log(
+                "WARNING: auth_type " . $self->auth_type . " not supported yet")
                 unless (lc($self->auth_type) eq 'none');
         }
     }
@@ -357,16 +363,17 @@ sub talk {
             return $payload
                 if (ref $payload eq 'HASH' && exists $payload->{error});
 
-            print "send payload: $payload\n" if $self->debug;
+            $self->log("send payload: $payload") if $self->debug;
         }
     }
 
     $uri = $oauth_req->to_url if ($self->auth_type eq 'oauth_params');
 
     if ($self->debug) {
-        print "uri: $method $uri\n";
-        print "extra header:\n" . Dumper($self->header) if (%{ $self->header });
-        print "OAuth header: " . $oauth_req->to_authorization_header . $/
+        $self->log("uri: $method $uri");
+        $self->log("extra header:\n" . dump($self->header))
+            if (%{ $self->header });
+        $self->log("OAuth header: " . $oauth_req->to_authorization_header)
             if ($self->auth_type eq 'oauth_header');
     }
 
@@ -396,7 +403,7 @@ sub talk {
     $self->agent->cookie_jar($self->cookies);
     my $response = $self->agent->request($request);
 
-    print "recv payload: " . $response->decoded_content . $/
+    $self->log("recv payload: " . $response->decoded_content)
         if $self->debug;
 
     # collect response headers
@@ -413,12 +420,11 @@ sub talk {
     };
 
     unless ($response->is_success || $response->is_redirect) {
-        print "error: "
-            . $response->status_line
-            . $/
-            . "message: "
-            . $response->decoded_content
-            . $/
+        $self->log("error: "
+                . $response->status_line
+                . $/
+                . "message: "
+                . $response->decoded_content)
             if $self->debug;
 
         $answer->{error} = "request failed: " . $response->status_line;
@@ -435,7 +441,7 @@ sub map_options {
 
     # check existence of mandatory attributes
     if ($command->{mandatory}) {
-        print "mandatory keys:\n" . Dumper(\@{ $command->{mandatory} })
+        $self->log("mandatory keys:\n" . dump(\@{ $command->{mandatory} }))
             if $self->debug;
 
         my @missing_attrs;
@@ -456,7 +462,7 @@ sub map_options {
 
     # then map everything in $options, overwriting detault_attributes if necessary
     if (keys %{ $self->mapping } and not $command->{no_mapping}) {
-        print "mapping hash:\n" . Dumper($self->mapping) if $self->debug;
+        $self->log("mapping hash:\n" . dump($self->mapping)) if $self->debug;
 
         # do the key and value mapping of options hash and overwrite defaults
         foreach my $key (keys %$options) {
@@ -480,7 +486,7 @@ sub map_options {
         wrap($options, $command->{wrapper} || $self->wrapper, $content_type)
         unless ($method =~ m/^(GET|HEAD|DELETE)$/);
 
-    print "options:\n" . Dumper($options) if $self->debug;
+    $self->log("options:\n" . dump($options)) if $self->debug;
 
     return $options;
 }
@@ -583,7 +589,7 @@ sub AUTOLOAD {
     my $response =
         $self->talk($self->commands->{$command}, $uri, $options, $content_type);
 
-    print "response:\n" . Dumper($response) if $self->debug;
+    $self->log("response:\n" . dump($response)) if $self->debug;
 
     return $response;
 }
@@ -601,7 +607,7 @@ Web::API - Web::API - A Simple base module to implement almost every RESTful API
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 SYNOPSIS
 
@@ -853,6 +859,8 @@ default: true
 
 generates new OAuth nonce for every request
 
+=head2 log
+
 =head2 decode
 
 =head2 encode
